@@ -15,4 +15,5 @@ grep -v 'clim' | \
 grep -v 'dlim' | \
 grep -v 'extend' | \
 grep -v 'learn' | \
-grep -v 'witness'
+grep -v 'witness' | \
+grep -v 'lrat'
