@@ -1,8 +1,8 @@
 #ifndef _cadical_hpp_INCLUDED
 #define _cadical_hpp_INCLUDED
 
-#include <cstdio>
 #include <cstdint>
+#include <cstdio>
 #include <vector>
 
 namespace CaDiCaL {
@@ -133,15 +133,16 @@ namespace CaDiCaL {
 //               terminate (asynchronously)
 //      SOLVING  ------------------------->  UNKNOWN
 //
-// The important behaviour to remember is that adding, assuming or constraining
-// a literal (immediately) destroys the satisfying assignment in the 'SATISFIED'
-// state and vice versa resets all assumptions in the 'UNSATISFIED' state. This
-// is exactly the behaviour required by the IPASIR interface.
+// The important behaviour to remember is that adding, assuming or
+// constraining a literal (immediately) destroys the satisfying assignment
+// in the 'SATISFIED' state and vice versa resets all assumptions in the
+// 'UNSATISFIED' state. This is exactly the behaviour required by the IPASIR
+// interface.
 //
 // Furthermore, the model can only be queried through 'val' in the
-// 'SATISFIED' state, while extracting failed assumptions with 'failed' only in
-// the 'UNSATISFIED' state.  Solving can only be started in the 'UNKNOWN' or
-// 'CONFIGURING' state or after the previous call to 'solve' yielded an
+// 'SATISFIED' state, while extracting failed assumptions with 'failed' only
+// in the 'UNSATISFIED' state.  Solving can only be started in the 'UNKNOWN'
+// or 'CONFIGURING' state or after the previous call to 'solve' yielded an
 // 'UNKNOWN, 'SATISFIED' or 'UNSATISFIED' state.
 //
 // All literals have to be valid literals too, i.e., 32-bit integers
@@ -162,21 +163,20 @@ namespace CaDiCaL {
 
 // States are represented by a bit-set in order to combine them.
 
-enum State
-{
-  INITIALIZING = 1,             // during initialization (invalid)
-  CONFIGURING  = 2,             // configure options (with 'set')
-  UNKNOWN      = 4,             // ready to call 'solve'
-  ADDING       = 8,             // adding clause literals (zero missing)
-  SOLVING      = 16,            // while solving (within 'solve')
-  SATISFIED    = 32,            // satisfiable allows 'val'
-  UNSATISFIED  = 64,            // unsatisfiable allows 'failed'
-  DELETING     = 128,           // during and after deletion (invalid)
+enum State {
+  INITIALIZING = 1, // during initialization (invalid)
+  CONFIGURING = 2,  // configure options (with 'set')
+  UNKNOWN = 4,      // ready to call 'solve'
+  ADDING = 8,       // adding clause literals (zero missing)
+  SOLVING = 16,     // while solving (within 'solve')
+  SATISFIED = 32,   // satisfiable allows 'val'
+  UNSATISFIED = 64, // unsatisfiable allows 'failed'
+  DELETING = 128,   // during and after deletion (invalid)
 
   // These combined states are used to check contracts.
 
-  READY   = CONFIGURING  | UNKNOWN | SATISFIED | UNSATISFIED,
-  VALID   = READY        | ADDING,
+  READY = CONFIGURING | UNKNOWN | SATISFIED | UNSATISFIED,
+  VALID = READY | ADDING,
   INVALID = INITIALIZING | DELETING
 };
 
@@ -196,13 +196,13 @@ class Learner;
 class Terminator;
 class ClauseIterator;
 class WitnessIterator;
+class ExternalPropagator;
 
 /*------------------------------------------------------------------------*/
 
 class Solver {
 
 public:
-
   // ====== BEGIN IPASIR ===================================================
 
   // This section implements the corresponding IPASIR functionality.
@@ -210,7 +210,7 @@ public:
   Solver ();
   ~Solver ();
 
-  static const char * signature ();     // name of this library
+  static const char *signature (); // name of this library
 
   // Core functionality as in the IPASIR incremental SAT solver interface.
   // (recall 'READY = CONFIGURING | UNKNOWN | SATISFIED | UNSATISFIED').
@@ -225,6 +225,8 @@ public:
   //
   void add (int lit);
 
+  bool inconsistent ();
+
   // Assume valid non zero literal for next call to 'solve'.  These
   // assumptions are reset after the call to 'solve' as well as after
   // returning from 'simplify' and 'lookahead.
@@ -257,6 +259,44 @@ public:
   //
   int val (int lit);
 
+  // Try to flip the value of the given literal without falsifying the
+  // formula.  Returns 'true' if this was successful. Otherwise the model is
+  // not changed and 'false' is returned.  If a literal was eliminated or
+  // substituted flipping will fail on that literal and in particular the
+  // solver will not taint it nor restore any clauses.
+  //
+  // The 'flip' function can only flip the value of a variables not acting
+  // as witness on the reconstruction stack.
+  //
+  // As a side effect of calling this function first all assigned variables
+  // are propagated again without using blocking literal.  Thus the first
+  // call to this function after obtaining a model adds a substantial
+  // overhead.  Subsequent calls will not need to properly propagate again.
+  //
+  // Furthermore if the reconstruction stack is non-empty and has been
+  // traversed to reconstruct a full extended model for eliminated
+  // variables (and to satisfy removed blocked clauses), the values of these
+  // witness variables obtained via 'val' before become invalid. The user
+  // thus will need to call 'val' again after calling 'flip' which will
+  // trigger then a traversal of the reconstruction stack.
+  //
+  // So try to avoid mixing 'flip' and 'val' (for efficiency only).
+  // Further, this functionality is currently not supported in the presence
+  // of an external propagator.
+  //
+  //   require (SATISFIED)
+  //   ensure (SATISFIED)
+  //
+  bool flip (int lit);
+
+  // Same as 'flip' without actually flipping it. This functionality is
+  // currently not supported in the presence of an external propagator.
+  //
+  //   require (SATISFIED)
+  //   ensure (SATISFIED)
+  //
+  bool flippable (int lit);
+
   // Determine whether the valid non-zero literal is in the core.
   // Returns 'true' if the literal is in the core and 'false' otherwise.
   // Note that the core does not have to be minimal.
@@ -273,7 +313,7 @@ public:
   //   require (VALID)
   //   ensure (VALID)
   //
-  void connect_terminator (Terminator * terminator);
+  void connect_terminator (Terminator *terminator);
   void disconnect_terminator ();
 
   // Add call-back which allows to export learned clauses.
@@ -281,29 +321,87 @@ public:
   //   require (VALID)
   //   ensure (VALID)
   //
-  void connect_learner (Learner * learner);
+  void connect_learner (Learner *learner);
   void disconnect_learner ();
 
   // ====== END IPASIR =====================================================
 
+  // ====== BEGIN IPASIR-UP ================================================
+
+  // Add call-back which allows to learn, propagate and backtrack based on
+  // external constraints. Only one external propagator can be connected
+  // and after connection every related variables must be 'observed' (use
+  // 'add_observed_var' function).
+  // Disconnection of the external propagator resets all the observed
+  // variables.
+  //
+  //   require (VALID)
+  //   ensure (VALID)
+  //
+  void connect_external_propagator (ExternalPropagator *propagator);
+  void disconnect_external_propagator ();
+
+  // Mark as 'observed' those variables that are relevant to the external
+  // propagator. External propagation, clause addition during search and
+  // notifications are all over these observed variabes.
+  // A variable can not be observed witouth having an external propagator
+  // connected. Observed variables are "frozen" internally, and so
+  // inprocessing will not consider them as candidates for elimination.
+  // An observed variable is allowed to be a fresh variable and it can be
+  // added also during solving.
+  //
+  //   require (VALID_OR_SOLVING)
+  //   ensure (VALID_OR_SOLVING)
+  //
+  void add_observed_var (int var);
+
+  // Removes the 'observed' flag from the given variable. A variable can be
+  // set unobserved only between solve calls, not during it (to guarantee
+  // that no yet unexplained external propagation involves it).
+  //
+  //   require (VALID)
+  //   ensure (VALID)
+  //
+  void remove_observed_var (int var);
+
+  // Removes all the 'observed' flags from the variables. Disconnecting the
+  // propagator invokes this step as well.
+  //
+  //   require (VALID)
+  //   ensure (VALID)
+  //
+  void reset_observed_vars ();
+
+  // Get reason of valid observed literal (true = it is an observed variable
+  // and it got assigned by a decision during the CDCL loop. Otherwise:
+  // false.
+  //
+  //   require (VALID_OR_SOLVING)
+  //   ensure (VALID_OR_SOLVING)
+  //
+  bool is_decision (int lit);
+
+  // ====== END IPASIR-UP ==================================================
+
   //------------------------------------------------------------------------
-  // Adds a literal to the constraint clause. Same functionality as 'add' but
-  // the clause only exists for the next call to solve (same lifetime as
-  // assumptions). Only one constraint may exists at a time. A new constraint
-  // replaces the old.
-  // The main application of this functonality is the model checking algorithm
-  // IC3. See our FMCAD'21 paper [FroleyksBiere-FMCAD'19] for more details.
+  // Adds a literal to the constraint clause. Same functionality as 'add'
+  // but the clause only exists for the next call to solve (same lifetime as
+  // assumptions). Only one constraint may exists at a time. A new
+  // constraint replaces the old. The main application of this functonality
+  // is the model checking algorithm IC3. See our FMCAD'21 paper
+  // [FroleyksBiere-FMCAD'19] for more details.
   //
   // Add valid literal to the constraint clause or zero to terminate it.
   //
-  //   require (VALID)                     // recall 'VALID = READY | ADDING'
-  //   if (lit) ensure (ADDING)            // and thus VALID but not READY
-  //   if (!lit) && !adding_clause ensure (UNKNOWN) // and thus READY
+  //   require (VALID)                     // recall 'VALID = READY |
+  //   ADDING' if (lit) ensure (ADDING)            // and thus VALID but not
+  //   READY if (!lit) && !adding_clause ensure (UNKNOWN) // and thus READY
   //
   void constrain (int lit);
 
-  // Determine whether the constraint was used to proof the unsatisfiability.
-  // Note that the formula might still be unsatisfiable without the constraint.
+  // Determine whether the constraint was used to proof the
+  // unsatisfiability. Note that the formula might still be unsatisfiable
+  // without the constraint.
   //
   //   require (UNSATISFIED)
   //   ensure (UNSATISFIED)
@@ -320,34 +418,37 @@ public:
   //   require (READY)
   //   ensure (UNKNOWN|SATISFIED|UNSATISFIED)
   //
-  int lookahead(void);
+  int lookahead (void);
 
   struct CubesWithStatus {
     int status;
     std::vector<std::vector<int>> cubes;
   };
 
-  CubesWithStatus generate_cubes(int, int min_depth = 0);
+  CubesWithStatus generate_cubes (int, int min_depth = 0);
 
   void reset_assumptions ();
   void reset_constraint ();
 
   // Return the current state of the solver as defined above.
   //
-  const State & state () const { return _state; }
+  const State &state () const { return _state; }
 
   // Similar to 'state ()' but using the staddard competition exit codes of
   // '10' for 'SATISFIABLE', '20' for 'UNSATISFIABLE' and '0' otherwise.
   //
   int status () const {
-         if (_state == SATISFIED)   return 10;
-    else if (_state == UNSATISFIED) return 20;
-    else                            return 0;
+    if (_state == SATISFIED)
+      return 10;
+    else if (_state == UNSATISFIED)
+      return 20;
+    else
+      return 0;
   }
 
   /*----------------------------------------------------------------------*/
 
-  static const char * version ();    // return version string
+  static const char *version (); // return version string
 
   /*----------------------------------------------------------------------*/
   // Copy 'this' into a fresh 'other'.  The copy procedure is not a deep
@@ -363,7 +464,7 @@ public:
   //   other.require (CONFIGURING)
   //   other.ensure (CONFIGURING | UNKNOWN)
   //
-  void copy (Solver & other) const;
+  void copy (Solver &other) const;
 
   /*----------------------------------------------------------------------*/
   // Variables are usually added and initialized implicitly whenever a
@@ -405,7 +506,7 @@ public:
   //   require (VALID)
   //   ensure (VALID)
   //
-  void trace_api_calls (FILE * file);
+  void trace_api_calls (FILE *file);
 #endif
 
   //------------------------------------------------------------------------
@@ -413,26 +514,26 @@ public:
 
   // Determine whether 'name' is a valid option name.
   //
-  static bool is_valid_option (const char * name);
+  static bool is_valid_option (const char *name);
 
   // Determine whether 'name' enables a specific preprocessing technique.
   //
-  static bool is_preprocessing_option (const char * name);
+  static bool is_preprocessing_option (const char *name);
 
   // Determine whether 'arg' is a valid long option of the form '--<name>',
   // '--<name>=<val>' or '--no-<name>' similar to 'set_long_option' below.
   // Legal values are 'true', 'false', or '[-]<mantissa>[e<exponent>]'.
 
-  static bool is_valid_long_option (const char * arg);
+  static bool is_valid_long_option (const char *arg);
 
   // Get the current value of the option 'name'.  If 'name' is invalid then
   // zero is returned.  Here '--...' arguments as invalid options.
   //
-  int get (const char * name);
+  int get (const char *name);
 
   // Set the default verbose message prefix (default "c ").
   //
-  void prefix (const char * verbose_message_prefix);
+  void prefix (const char *verbose_message_prefix);
 
   // Explicit version of setting an option.  If the option '<name>' exists
   // and '<val>' can be parsed then 'true' is returned.  If the option value
@@ -444,7 +545,7 @@ public:
   //
   // Thus options can only bet set right after initialization.
   //
-  bool set (const char * name, int val);
+  bool set (const char *name, int val);
 
   // This function accepts options in command line syntax:
   //
@@ -459,7 +560,7 @@ public:
   //   require (CONFIGURING)
   //   ensure (CONFIGURING)
   //
-  bool set_long_option (const char * arg);
+  bool set_long_option (const char *arg);
 
   // Determine whether 'name' is a valid configuration.
   //
@@ -498,8 +599,8 @@ public:
   //   require (READY)
   //   ensure (READY)
   //
-  bool limit (const char * arg, int val);
-  bool is_valid_limit (const char * arg);
+  bool limit (const char *arg, int val);
+  bool is_valid_limit (const char *arg);
 
   // The number of currently active variables and clauses can be queried by
   // these functions.  Variables become active if a clause is added with it.
@@ -570,7 +671,7 @@ public:
   //
   bool frozen (int lit) const;
   void freeze (int lit);
-  void melt (int lit);          // Also needs 'require (frozen (lit))'.
+  void melt (int lit); // Also needs 'require (frozen (lit))'.
 
   //------------------------------------------------------------------------
 
@@ -599,8 +700,8 @@ public:
   //   require (CONFIGURING)
   //   ensure (CONFIGURING)
   //
-  bool trace_proof (FILE * file, const char * name); // Write DRAT proof.
-  bool trace_proof (const char * path);              // Open & write proof.
+  bool trace_proof (FILE *file, const char *name); // Write DRAT proof.
+  bool trace_proof (const char *path);             // Open & write proof.
 
   // Flush proof trace file.
   //
@@ -625,13 +726,13 @@ public:
   //   require (!DELETING)
   //   ensure (!DELETING)
   //
-  void statistics ();   // print statistics
-  void resources ();    // print resource usage (time and memory)
+  void statistics (); // print statistics
+  void resources ();  // print resource usage (time and memory)
 
   //   require (VALID)
   //   ensure (VALID)
   //
-  void options ();      // print current option and value list
+  void options (); // print current option and value list
 
   //------------------------------------------------------------------------
   // Traverse irredundant clauses or the extension stack in reverse order.
@@ -663,10 +764,10 @@ public:
   //   require (VALID)
   //   ensure (VALID)
   //
-  const char * read_dimacs (FILE * file,
-                            const char * name, int & vars, int strict = 1);
+  const char *read_dimacs (FILE *file, const char *name, int &vars,
+                           int strict = 1);
 
-  const char * read_dimacs (const char * path, int & vars, int strict = 1);
+  const char *read_dimacs (const char *path, int &vars, int strict = 1);
 
   // The following routines work the same way but parse both DIMACS and
   // INCCNF files (with 'p inccnf' header and 'a <cube>' lines).  If the
@@ -674,12 +775,12 @@ public:
   // to true and the cubes are stored in the given vector (each cube
   // terminated by a zero).
 
-  const char * read_dimacs (FILE * file,
-                            const char * name, int & vars, int strict,
-                            bool & incremental, std::vector<int> & cubes);
+  const char *read_dimacs (FILE *file, const char *name, int &vars,
+                           int strict, bool &incremental,
+                           std::vector<int> &cubes);
 
-  const char * read_dimacs (const char * path, int & vars, int strict,
-                            bool & incremental, std::vector<int> & cubes);
+  const char *read_dimacs (const char *path, int &vars, int strict,
+                           bool &incremental, std::vector<int> &cubes);
 
   //------------------------------------------------------------------------
   // Write current irredundant clauses and all derived unit clauses
@@ -694,19 +795,18 @@ public:
   //   require (VALID)
   //   ensure (VALID)
   //
-  const char * write_dimacs (const char * path, int min_max_var = 0);
+  const char *write_dimacs (const char *path, int min_max_var = 0);
 
   // The extension stack for reconstruction a solution can be written too.
   //
-  const char * write_extension (const char * path);
+  const char *write_extension (const char *path);
 
   // Print build configuration to a file with prefix 'c '.  If the file
   // is '<stdout>' or '<stderr>' then terminal color codes might be used.
   //
-  static void build (FILE * file, const char * prefix = "c ");
+  static void build (FILE *file, const char *prefix = "c ");
 
 private:
-
   //==== start of state ====================================================
 
   // The solver is in the state ADDING if either the current clause or the
@@ -714,7 +814,7 @@ private:
   bool adding_clause;
   bool adding_constraint;
 
-  State _state;            // API states as discussed above.
+  State _state; // API states as discussed above.
 
   /*----------------------------------------------------------------------*/
 
@@ -752,8 +852,8 @@ private:
   // necessary, if we want to use extended resolution in the future (such as
   // bounded variable addition).
   //
-  Internal * internal;     // Hidden internal solver.
-  External * external;     // Hidden API to internal solver mapping.
+  Internal *internal; // Hidden internal solver.
+  External *external; // Hidden API to internal solver mapping.
 
 #ifndef NTRACING
   // The API calls to the solver can be traced by setting the environment
@@ -767,7 +867,7 @@ private:
   // Alternatively one case use 'trace_api_calls'.  Both
   //
   bool close_trace_api_file; // Close file if owned by solver it.
-  FILE * trace_api_file;     // Also acts as flag that we are tracing.
+  FILE *trace_api_file;      // Also acts as flag that we are tracing.
 
   static bool tracing_api_through_environment;
 
@@ -775,6 +875,7 @@ private:
 
   void trace_api_call (const char *) const;
   void trace_api_call (const char *, int) const;
+  void trace_api_call (const char *, const char *) const;
   void trace_api_call (const char *, const char *, int) const;
 #endif
 
@@ -795,42 +896,45 @@ private:
   //   require (VALID)
   //   ensure (VALID)
   //
-  const char * read_solution (const char * path);
+  const char *read_solution (const char *path);
 
   // Cross-compilation with 'MinGW' needs some work-around for 'printf'
   // style printing of 64-bit numbers including warning messages.  The
   // followings lines are copies of similar code in 'inttypes.hpp' but we
   // want to keep the 'cadical.hpp' header file stand-alone.
 
-# ifndef PRINTF_FORMAT
-#   ifdef __MINGW32__
-#     define __USE_MINGW_ANSI_STDIO 1
-#     define PRINTF_FORMAT __MINGW_PRINTF_FORMAT
-#   else
-#     define PRINTF_FORMAT printf
-#   endif
-# endif
+#ifndef PRINTF_FORMAT
+#ifdef __MINGW32__
+#define __USE_MINGW_ANSI_STDIO 1
+#define PRINTF_FORMAT __MINGW_PRINTF_FORMAT
+#else
+#define PRINTF_FORMAT printf
+#endif
+#endif
 
-  // This gives warning messages for wrong 'printf' style format string usage.
-  // Apparently (on 'gcc 9' at least) the first argument is 'this' here.
+  // This gives warning messages for wrong 'printf' style format string
+  // usage. Apparently (on 'gcc 9' at least) the first argument is 'this'
+  // here.
   //
   // TODO: support for other compilers (beside 'gcc' and 'clang').
 
-# define CADICAL_ATTRIBUTE_FORMAT(FORMAT_POSITION,VARIADIC_ARGUMENT_POSITION) \
-    __attribute__ ((format (PRINTF_FORMAT, FORMAT_POSITION, VARIADIC_ARGUMENT_POSITION)))
+#define CADICAL_ATTRIBUTE_FORMAT(FORMAT_POSITION, \
+                                 VARIADIC_ARGUMENT_POSITION) \
+  __attribute__ ((format (PRINTF_FORMAT, FORMAT_POSITION, \
+                          VARIADIC_ARGUMENT_POSITION)))
 
   // Messages in a common style.
   //
   //   require (VALID | DELETING)
   //   ensure (VALID | DELETING)
   //
-  void section (const char *);          // print section header
-  void message (const char *, ...)      // ordinary message
-                CADICAL_ATTRIBUTE_FORMAT (2, 3);
+  void section (const char *);     // print section header
+  void message (const char *, ...) // ordinary message
+      CADICAL_ATTRIBUTE_FORMAT (2, 3);
 
-  void message ();                      // empty line - only prefix
-  void error (const char *, ...)        // produce error message
-              CADICAL_ATTRIBUTE_FORMAT (2, 3);
+  void message ();               // empty line - only prefix
+  void error (const char *, ...) // produce error message
+      CADICAL_ATTRIBUTE_FORMAT (2, 3);
 
   // Explicit verbose level ('section' and 'message' use '0').
   //
@@ -838,16 +942,15 @@ private:
   //   ensure (VALID | DELETING)
   //
   void verbose (int level, const char *, ...)
-                           CADICAL_ATTRIBUTE_FORMAT (3, 4);
+      CADICAL_ATTRIBUTE_FORMAT (3, 4);
 
   // Factoring out common code to both 'read_dimacs' functions above.
   //
   //   require (VALID)
   //   ensure (VALID)
   //
-  const char * read_dimacs (File *, int &, int strict,
-                            bool * incremental = 0,
-                            std::vector<int> * = 0);
+  const char *read_dimacs (File *, int &, int strict, bool *incremental = 0,
+                           std::vector<int> * = 0);
 
   // Factored out common code for 'solve', 'simplify' and 'lookahead'.
   //
@@ -864,6 +967,20 @@ private:
   //
   void dump_cnf ();
   friend struct DumpCall; // Mobical calls 'dump_cnf' in 'DumpCall::execute'
+
+  /*----------------------------------------------------------------------*/
+
+  // Used in mobical to test external propagation internally.
+  // These functions should not be called for any other purposes.
+  //
+  ExternalPropagator *get_propagator ();
+  bool observed (int lit);
+  bool is_witness (int lit);
+
+  friend struct LemmaCall;
+  friend struct ObserveCall;
+  friend struct DisconnectCall;
+  friend class MockPropagator;
 };
 
 /*========================================================================*/
@@ -874,7 +991,7 @@ private:
 
 class Terminator {
 public:
-  virtual ~Terminator () { }
+  virtual ~Terminator () {}
   virtual bool terminate () = 0;
 };
 
@@ -885,13 +1002,90 @@ public:
 
 class Learner {
 public:
-  virtual ~Learner () { }
+  virtual ~Learner () {}
   virtual bool learning (int size) = 0;
   virtual void learn (int lit) = 0;
 };
 
 /*------------------------------------------------------------------------*/
 
+// Allows to connect an external propagator to propagate values to variables
+// with an external clause as a reason or to learn new clauses during the
+// CDCL loop (without restart).
+
+class ExternalPropagator {
+
+public:
+  // This flag is currently checked only when the propagator is connected.
+  bool is_lazy = false; // lazy propagator only checks complete assignments
+
+  virtual ~ExternalPropagator () {}
+
+  // Notify the propagator about assignments to observed variables.
+  // The notification is not necessarily eager. It usually happens before
+  // the call of propagator callbacks and when a driving clause is leading
+  // to an assignment.
+  //
+  virtual void notify_assignment (int lit, bool is_fixed) = 0;
+  virtual void notify_new_decision_level () = 0;
+  virtual void notify_backtrack (size_t new_level) = 0;
+
+  // Check by the external propagator the found complete solution (after
+  // solution reconstruction). If it returns false, the propagator must
+  // provide an external clause during the next callback.
+  //
+  virtual bool cb_check_found_model (const std::vector<int> &model) = 0;
+
+  // Ask the external propagator for the next decision literal. If it
+  // returns 0, the solver makes its own choice.
+  //
+  virtual int cb_decide () { return 0; };
+
+  // Ask the external propagator if there is an external propagation to make
+  // under the current assignment. It returns either a literal to be
+  // propagated or 0, indicating that there is no external propagation under
+  // the current assignment.
+  //
+  virtual int cb_propagate () { return 0; };
+
+  // Ask the external propagator for the reason clause of a previous
+  // external propagation step (done by cb_propagate). The clause must be
+  // added literal-by-literal closed with a 0. Further, the clause must
+  // contain the propagated literal.
+  //
+  virtual int cb_add_reason_clause_lit (int propagated_lit) {
+    (void) propagated_lit;
+    return 0;
+  };
+
+  // The following two functions are used to add external clauses to the
+  // solver during the CDCL loop. The external clause is added
+  // literal-by-literal and learned by the solver as an irredundant
+  // (original) input clause. The clause can be arbitrary, but if it is
+  // root-satisfied or tautology, the solver will ignore it without learning
+  // it. Root-falsified literals are eagerly removed from the clause.
+  // Falsified clauses trigger conflict analysis, propagating clauses
+  // trigger propagation. In case chrono is 0, the solver backtracks to
+  // propagate the new literal on the right decision level, otherwise it
+  // potentially will be an out-of-order assignment on the current level.
+  // Unit clauses always (unless root-satisfied, see above) trigger
+  // backtracking (independently from the value of the chrono option and
+  // independently from being falsified or satisfied or unassigned) to level
+  // 0. Empty clause (or root falsified clause, see above) makes the problem
+  // unsat and stops the search immediately. A literal 0 must close the
+  // clause.
+  //
+  // The external propagator indicates that there is a clause to add.
+  //
+  virtual bool cb_has_external_clause () = 0;
+
+  // The actual function called to add the external clause.
+  //
+  virtual int cb_add_external_clause_lit () = 0;
+};
+
+/*------------------------------------------------------------------------*/
+
 // Allows to traverse all remaining irredundant clauses.  Satisfied and
 // eliminated clauses are not included, nor any derived units unless such
 // a unit literal is frozen. Falsified literals are skipped.  If the solver
@@ -901,7 +1095,7 @@ public:
 
 class ClauseIterator {
 public:
-  virtual ~ClauseIterator () { }
+  virtual ~ClauseIterator () {}
   virtual bool clause (const std::vector<int> &) = 0;
 };
 
@@ -924,13 +1118,13 @@ public:
 
 class WitnessIterator {
 public:
-  virtual ~WitnessIterator () { }
-  virtual bool witness (const std::vector<int> & clause,
-                        const std::vector<int> & witness) = 0;
+  virtual ~WitnessIterator () {}
+  virtual bool witness (const std::vector<int> &clause,
+                        const std::vector<int> &witness) = 0;
 };
 
 /*------------------------------------------------------------------------*/
 
-}
+} // namespace CaDiCaL
 
 #endif
