@@ -2,48 +2,48 @@
 
 namespace CaDiCaL {
 
-External::External (Internal * i)
-:
-  internal (i),
-  max_var (0),
-  vsize (0),
-  extended (false),
-  terminator (0),
-  learner (0),
-  solution (0),
-  vars (max_var)
-{
+External::External (Internal *i)
+    : internal (i), max_var (0), vsize (0), extended (false),
+      terminator (0), learner (0), propagator (0), solution (0),
+      vars (max_var) {
   assert (internal);
   assert (!internal->external);
   internal->external = this;
 }
 
 External::~External () {
-  if (solution) delete [] solution;
+  if (solution)
+    delete[] solution;
 }
 
 void External::enlarge (int new_max_var) {
 
   assert (!extended);
 
-  size_t new_vsize = vsize ? 2*vsize : 1 + (size_t) new_max_var;
-  while (new_vsize <= (size_t) new_max_var) new_vsize *= 2;
+  size_t new_vsize = vsize ? 2 * vsize : 1 + (size_t) new_max_var;
+  while (new_vsize <= (size_t) new_max_var)
+    new_vsize *= 2;
   LOG ("enlarge external size from %zd to new size %zd", vsize, new_vsize);
   vsize = new_vsize;
 }
 
 void External::init (int new_max_var) {
   assert (!extended);
-  if (new_max_var <= max_var) return;
+  if (new_max_var <= max_var)
+    return;
   int new_vars = new_max_var - max_var;
   int old_internal_max_var = internal->max_var;
   int new_internal_max_var = old_internal_max_var + new_vars;
   internal->init_vars (new_internal_max_var);
-  if ((size_t) new_max_var >= vsize) enlarge (new_max_var);
+  if ((size_t) new_max_var >= vsize)
+    enlarge (new_max_var);
   LOG ("initialized %d external variables", new_vars);
   if (!max_var) {
     assert (e2i.empty ());
     e2i.push_back (0);
+    ext_units.push_back (0);
+    ext_units.push_back (0);
+    ext_flags.push_back (0);
     assert (internal->i2e.empty ());
     internal->i2e.push_back (0);
   } else {
@@ -51,21 +51,26 @@ void External::init (int new_max_var) {
     assert (internal->i2e.size () == (size_t) old_internal_max_var + 1);
   }
   unsigned iidx = old_internal_max_var + 1, eidx;
-  for (eidx = max_var + 1u;
-       eidx <= (unsigned) new_max_var;
+  for (eidx = max_var + 1u; eidx <= (unsigned) new_max_var;
        eidx++, iidx++) {
     LOG ("mapping external %u to internal %u", eidx, iidx);
     assert (e2i.size () == eidx);
     e2i.push_back (iidx);
+    ext_units.push_back (0);
+    ext_units.push_back (0);
+    ext_flags.push_back (0);
     internal->i2e.push_back (eidx);
     assert (internal->i2e[iidx] == (int) eidx);
     assert (e2i[eidx] == (int) iidx);
   }
+  if (new_max_var >= (int64_t) is_observed.size ())
+    is_observed.resize (1 + (size_t) new_max_var, false);
   if (internal->opts.checkfrozen)
     if (new_max_var >= (int64_t) moltentab.size ())
       moltentab.resize (1 + (size_t) new_max_var, false);
   assert (iidx == (size_t) new_internal_max_var + 1);
   assert (eidx == (size_t) new_max_var + 1);
+  assert (ext_units.size () == (size_t) new_max_var * 2 + 2);
   max_var = new_max_var;
 }
 
@@ -82,14 +87,13 @@ void External::reset_constraint () {
 }
 
 void External::reset_extended () {
-  if (!extended) return;
+  if (!extended)
+    return;
   LOG ("reset extended");
   extended = false;
 }
 
-void External::reset_limits () {
-  internal->reset_limits ();
-}
+void External::reset_limits () { internal->reset_limits (); }
 
 /*------------------------------------------------------------------------*/
 
@@ -98,9 +102,11 @@ int External::internalize (int elit) {
   if (elit) {
     assert (elit != INT_MIN);
     const int eidx = abs (elit);
-    if (eidx > max_var) init (eidx);
-    ilit = e2i [eidx];
-    if (elit < 0) ilit = -ilit;
+    if (eidx > max_var)
+      init (eidx);
+    ilit = e2i[eidx];
+    if (elit < 0)
+      ilit = -ilit;
     if (!ilit) {
       assert (internal->max_var < INT_MAX);
       ilit = internal->max_var + 1u;
@@ -111,23 +117,26 @@ int External::internalize (int elit) {
       internal->i2e.push_back (eidx);
       assert (internal->i2e[ilit] == eidx);
       assert (e2i[eidx] == ilit);
-      if (elit < 0) ilit = -ilit;
+      if (elit < 0)
+        ilit = -ilit;
     }
     if (internal->opts.checkfrozen) {
       assert (eidx < (int64_t) moltentab.size ());
       if (moltentab[eidx])
         FATAL ("can not reuse molten literal %d", eidx);
     }
-    Flags & f = internal->flags (ilit);
-    if (f.status == Flags::UNUSED) internal->mark_active (ilit);
-    else if (f.status != Flags::ACTIVE &&
-             f.status != Flags::FIXED) internal->reactivate (ilit);
+    Flags &f = internal->flags (ilit);
+    if (f.status == Flags::UNUSED)
+      internal->mark_active (ilit);
+    else if (f.status != Flags::ACTIVE && f.status != Flags::FIXED)
+      internal->reactivate (ilit);
     if (!marked (tainted, elit) && marked (witness, -elit)) {
       assert (!internal->opts.checkfrozen);
       LOG ("marking tainted %d", elit);
       mark (tainted, elit);
     }
-  } else ilit = 0;
+  } else
+    ilit = 0;
   return ilit;
 }
 
@@ -137,10 +146,41 @@ void External::add (int elit) {
   if (internal->opts.check &&
       (internal->opts.checkwitness || internal->opts.checkfailed))
     original.push_back (elit);
+
   const int ilit = internalize (elit);
   assert (!elit == !ilit);
-  if (elit) LOG ("adding external %d as internal %d", elit, ilit);
+
+  // The external literals of the new clause must be saved for later
+  // when the proof is printed during add_original_lit (0)
+  if (elit && internal->proof) {
+    eclause.push_back (elit);
+    if (internal->opts.lrat && !internal->opts.lratexternal) {
+      // actually find unit of -elit (flips elit < 0)
+      unsigned eidx = (elit > 0) + 2u * (unsigned) abs (elit);
+      assert ((size_t) eidx < ext_units.size ());
+      const uint64_t id = ext_units[eidx];
+      bool added = ext_flags[abs (elit)];
+      if (id && !added) {
+        ext_flags[abs (elit)] = true;
+        internal->lrat_chain.push_back (id);
+      }
+    }
+  }
+
+  if (!elit && internal->proof && internal->opts.lrat &&
+      !internal->opts.lratexternal) {
+    for (const auto &elit : eclause) {
+      ext_flags[abs (elit)] = false;
+    }
+  }
+
+  if (elit)
+    LOG ("adding external %d as internal %d", elit, ilit);
   internal->add_original_lit (ilit);
+
+  // Clean-up saved external literals once proof line is printed
+  if (!elit && internal->proof)
+    eclause.clear ();
 }
 
 void External::assume (int elit) {
@@ -153,14 +193,52 @@ void External::assume (int elit) {
   internal->assume (ilit);
 }
 
+bool External::flip (int elit) {
+  assert (elit);
+  assert (elit != INT_MIN);
+  assert (!propagator);
+
+  int eidx = abs (elit);
+  if (eidx > max_var)
+    return false;
+  if (marked (witness, elit))
+    return false;
+  int ilit = e2i[eidx];
+  if (!ilit)
+    return false;
+  bool res = internal->flip (ilit);
+  if (res && extended)
+    reset_extended ();
+  return res;
+}
+
+bool External::flippable (int elit) {
+  assert (elit);
+  assert (elit != INT_MIN);
+  assert (!propagator);
+
+  int eidx = abs (elit);
+  if (eidx > max_var)
+    return false;
+  if (marked (witness, elit))
+    return false;
+  int ilit = e2i[eidx];
+  if (!ilit)
+    return false;
+  return internal->flippable (ilit);
+}
+
 bool External::failed (int elit) {
   assert (elit);
   assert (elit != INT_MIN);
   int eidx = abs (elit);
-  if (eidx > max_var) return 0;
+  if (eidx > max_var)
+    return 0;
   int ilit = e2i[eidx];
-  if (!ilit) return 0;
-  if (elit < 0) ilit = -ilit;
+  if (!ilit)
+    return 0;
+  if (elit < 0)
+    ilit = -ilit;
   return internal->failed (ilit);
 }
 
@@ -174,7 +252,8 @@ void External::constrain (int elit) {
   constraint.push_back (elit);
   const int ilit = internalize (elit);
   assert (!elit == !ilit);
-  if (elit) LOG ("adding external %d as internal %d to constraint", elit, ilit);
+  if (elit)
+    LOG ("adding external %d as internal %d to constraint", elit, ilit);
   internal->constrain (ilit);
 }
 
@@ -186,10 +265,16 @@ void External::phase (int elit) {
   assert (elit);
   assert (elit != INT_MIN);
   int eidx = abs (elit);
-  if (eidx > max_var) return;
+  if (eidx > max_var) {
+  UNUSED:
+    LOG ("forcing phase of unused external %d ignored", elit);
+    return;
+  }
   int ilit = e2i[eidx];
-  if (!ilit) return;
-  if (elit < 0) ilit = -ilit;
+  if (!ilit)
+    goto UNUSED;
+  if (elit < 0)
+    ilit = -ilit;
   internal->phase (ilit);
 }
 
@@ -197,20 +282,163 @@ void External::unphase (int elit) {
   assert (elit);
   assert (elit != INT_MIN);
   int eidx = abs (elit);
-  if (eidx > max_var) return;
+  if (eidx > max_var) {
+  UNUSED:
+    LOG ("resetting forced phase of unused external %d ignored", elit);
+    return;
+  }
   int ilit = e2i[eidx];
-  if (!ilit) return;
-  if (elit < 0) ilit = -ilit;
+  if (!ilit)
+    goto UNUSED;
+  if (elit < 0)
+    ilit = -ilit;
   internal->unphase (ilit);
 }
 
 /*------------------------------------------------------------------------*/
 
+// External propagation related functions
+
+void External::add_observed_var (int elit) {
+  if (!propagator) {
+    LOG ("No connected propagator that could observe the variable, "
+         "observed flag is not set.");
+    return;
+  }
+
+  assert (elit);
+  assert (elit != INT_MIN);
+  reset_extended (); // tainting!
+
+  int eidx = abs (elit);
+  if (eidx <= max_var &&
+      (marked (witness, elit) || marked (witness, -elit))) {
+    LOG ("Error, only clean variables are allowed to become observed.");
+    assert (false);
+
+    // TODO: here needs to come the taint and restore of the newly
+    // observed variable. Restore_clauses must be called before continue.
+    // LOG ("marking tainted %d", elit);
+    // mark (tainted, elit);
+    // mark (tainted, -elit);
+    // restore_clauses ...
+  }
+
+  if (eidx >= (int64_t) is_observed.size ())
+    is_observed.resize (1 + (size_t) eidx, false);
+
+  if (is_observed[eidx])
+    return;
+
+  LOG ("marking %d as externally watched", eidx);
+
+  // Will do the necessary internalization
+  freeze (elit);
+  is_observed[eidx] = true;
+
+  int ilit = internalize (elit);
+  internal->add_observed_var (ilit);
+
+  if (propagator->is_lazy)
+    return;
+
+  // Fixed variables are notified only upon assignment. In case
+  // this variable was already assigned (e.g. via unit clause),
+  // it must be notified explicitly now. (-> Can cause a repeated fixed
+  // assignment notification, in case it was unobserved and observed again.)
+  const int tmp = fixed (elit);
+  if (!tmp)
+    return;
+  int unit = tmp < 0 ? -elit : elit;
+
+  LOG ("notify propagator about fixed assignment upon observe for %d",
+       unit);
+  propagator->notify_assignment (unit, true);
+}
+
+void External::remove_observed_var (int elit) {
+  if (!propagator) {
+    LOG ("No connected propagator that could have watched the variable");
+    return;
+  }
+  int eidx = abs (elit);
+
+  if (eidx > max_var)
+    return;
+
+  if (is_observed[eidx]) {
+    // Follow opposite order of add_observed_var, first remove internal
+    // is_observed
+    int ilit = e2i[eidx]; // internalize (elit);
+    internal->remove_observed_var (ilit);
+
+    is_observed[eidx] = false;
+    melt (elit);
+    LOG ("unmarking %d as externally watched", eidx);
+  }
+}
+
+void External::reset_observed_vars () {
+  // Shouldn't be called if there is no connected propagator
+  assert (propagator);
+  reset_extended ();
+  assert ((size_t) max_var + 1 == is_observed.size ());
+
+  for (auto elit : vars) {
+    int eidx = abs (elit);
+    assert (eidx <= max_var);
+    if (is_observed[eidx]) {
+      int ilit = internalize (elit);
+      internal->remove_observed_var (ilit);
+      LOG ("unmarking %d as externally watched", eidx);
+      is_observed[eidx] = false;
+      melt (elit);
+    }
+  }
+  internal->notified = 0;
+  LOG ("reset notified counter to 0");
+}
+
+bool External::observed (int elit) {
+  assert (elit);
+  assert (elit != INT_MIN);
+  int eidx = abs (elit);
+  if (eidx > max_var)
+    return false;
+  if (eidx >= (int) is_observed.size ())
+    return false;
+
+  return is_observed[eidx];
+}
+
+bool External::is_witness (int elit) {
+  assert (elit);
+  assert (elit != INT_MIN);
+  int eidx = abs (elit);
+  if (eidx > max_var)
+    return false;
+  return (marked (witness, elit) || marked (witness, -elit));
+}
+
+bool External::is_decision (int elit) {
+  assert (elit);
+  assert (elit != INT_MIN);
+  int eidx = abs (elit);
+  if (eidx > max_var)
+    return false;
+
+  int ilit = internalize (elit);
+  return internal->is_decision (ilit);
+}
+
+/*------------------------------------------------------------------------*/
+
 // Internal checker if 'solve' claims the formula to be satisfiable.
 
 void External::check_satisfiable () {
   LOG ("checking satisfiable");
-  if (!extended) extend ();
+  if (!extended)
+    extend ();
   if (internal->opts.checkwitness)
     check_assignment (&External::ival);
   if (internal->opts.checkassumptions && !assumptions.empty ())
@@ -223,7 +451,8 @@ void External::check_satisfiable () {
 
 void External::check_unsatisfiable () {
   LOG ("checking unsatisfiable");
-  if (!internal->opts.checkfailed) return;
+  if (!internal->opts.checkfailed)
+    return;
   if (!assumptions.empty () || !constraint.empty ())
     check_failing ();
 }
@@ -231,9 +460,12 @@ void External::check_unsatisfiable () {
 // Check result of 'solve' to be correct.
 
 void External::check_solve_result (int res) {
-  if (!internal->opts.check) return;
-  if (res == 10) check_satisfiable ();
-  if (res == 20) check_unsatisfiable ();
+  if (!internal->opts.check)
+    return;
+  if (res == 10)
+    check_satisfiable ();
+  if (res == 20)
+    check_unsatisfiable ();
 }
 
 // Prepare checking that completely molten literals are not used as argument
@@ -242,20 +474,27 @@ void External::check_solve_result (int res) {
 // for checking the deprecated 'freeze' semantics.
 
 void External::update_molten_literals () {
-  if (!internal->opts.checkfrozen) return;
+  if (!internal->opts.checkfrozen)
+    return;
   assert ((size_t) max_var + 1 == moltentab.size ());
+#ifdef LOGGING
   int registered = 0, molten = 0;
+#endif
   for (auto lit : vars) {
     if (moltentab[lit]) {
       LOG ("skipping already molten literal %d", lit);
+#ifdef LOGGING
       molten++;
+#endif
     } else if (frozen (lit))
       LOG ("skipping currently frozen literal %d", lit);
     else {
       LOG ("new molten literal %d", lit);
       moltentab[lit] = true;
+#ifdef LOGGING
       registered++;
       molten++;
+#endif
     }
   }
   LOG ("registered %d new molten literals", registered);
@@ -277,27 +516,29 @@ int External::lookahead () {
   reset_extended ();
   update_molten_literals ();
   int ilit = internal->lookahead ();
-  const int elit = (ilit && ilit != INT_MIN) ? internal->externalize (ilit) : 0;
+  const int elit =
+      (ilit && ilit != INT_MIN) ? internal->externalize (ilit) : 0;
   LOG ("lookahead internal %d external %d", ilit, elit);
   return elit;
 }
 
-CaDiCaL::CubesWithStatus External::generate_cubes (int depth, int min_depth = 0) {
+CaDiCaL::CubesWithStatus External::generate_cubes (int depth,
+                                                   int min_depth = 0) {
   reset_extended ();
   update_molten_literals ();
   reset_limits ();
   auto cubes = internal->generate_cubes (depth, min_depth);
-  auto externalize = [this](int ilit) {
+  auto externalize = [this] (int ilit) {
     const int elit = ilit ? internal->externalize (ilit) : 0;
     MSG ("lookahead internal %d external %d", ilit, elit);
     return elit;
   };
-  auto externalize_map = [this, externalize](std::vector<int> cube) {
+  auto externalize_map = [this, externalize] (std::vector<int> cube) {
     (void) this;
-    MSG("Cube : ");
-    std::for_each(begin(cube), end(cube), externalize);
+    MSG ("Cube : ");
+    std::for_each (begin (cube), end (cube), externalize);
   };
-  std::for_each(begin(cubes.cubes), end(cubes.cubes), externalize_map);
+  std::for_each (begin (cubes.cubes), end (cubes.cubes), externalize_map);
 
   return cubes;
 }
@@ -309,12 +550,12 @@ void External::freeze (int elit) {
   int ilit = internalize (elit);
   unsigned eidx = vidx (elit);
   if (eidx >= frozentab.size ())
-    frozentab.resize (eidx + 1,  0);
-  unsigned & ref = frozentab[eidx];
+    frozentab.resize (eidx + 1, 0);
+  unsigned &ref = frozentab[eidx];
   if (ref < UINT_MAX) {
     ref++;
-    LOG ("external variable %d frozen once and now frozen %u times",
-      eidx, ref);
+    LOG ("external variable %d frozen once and now frozen %u times", eidx,
+         ref);
   } else
     LOG ("external variable %d frozen but remains frozen forever", eidx);
   internal->freeze (ilit);
@@ -325,15 +566,21 @@ void External::melt (int elit) {
   int ilit = internalize (elit);
   unsigned eidx = vidx (elit);
   assert (eidx < frozentab.size ());
-  unsigned & ref = frozentab[eidx];
+  unsigned &ref = frozentab[eidx];
   assert (ref > 0);
   if (ref < UINT_MAX) {
-    if (!--ref)
-      LOG ("external variable %d melted once and now completely melted",
-        eidx);
-    else
+    if (!--ref) {
+      if (observed (elit)) {
+        ref++;
+        LOG ("external variable %d is observed, can not be completely "
+             "molten",
+             eidx);
+      } else
+        LOG ("external variable %d melted once and now completely melted",
+             eidx);
+    } else
       LOG ("external variable %d melted once but remains frozen %u times",
-        eidx, ref);
+           eidx, ref);
   } else
     LOG ("external variable %d melted but remains frozen forever", eidx);
   internal->melt (ilit);
@@ -341,13 +588,14 @@ void External::melt (int elit) {
 
 /*------------------------------------------------------------------------*/
 
-void External::check_assignment (int (External::*a)(int) const) {
+void External::check_assignment (int (External::*a) (int) const) {
 
   // First check all assigned and consistent.
   //
   for (auto idx : vars) {
-    if (!(this->*a) (idx)) FATAL ("unassigned variable: %d", idx);
-    if ((this->*a) (idx) != -(this->*a)(-idx))
+    if (!(this->*a) (idx))
+      FATAL ("unassigned variable: %d", idx);
+    if ((this->*a) (idx) != -(this->*a) (-idx))
       FATAL ("inconsistently assigned literals %d and %d", idx, -idx);
   }
 
@@ -356,7 +604,9 @@ void External::check_assignment (int (External::*a)(int) const) {
   bool satisfied = false;
   const auto end = original.end ();
   auto start = original.begin (), i = start;
+#ifndef QUIET
   int64_t count = 0;
+#endif
   for (; i != end; i++) {
     int lit = *i;
     if (!lit) {
@@ -370,26 +620,29 @@ void External::check_assignment (int (External::*a)(int) const) {
       }
       satisfied = false;
       start = i + 1;
+#ifndef QUIET
       count++;
-    } else if (!satisfied && (this->*a) (lit) > 0) satisfied = true;
+#endif
+    } else if (!satisfied && (this->*a) (lit) > 0)
+      satisfied = true;
   }
-  VERBOSE (1,
-    "satisfying assignment checked on %" PRId64 " clauses",
-    count);
+  VERBOSE (1, "satisfying assignment checked on %" PRId64 " clauses",
+           count);
 }
 
 /*------------------------------------------------------------------------*/
 
 void External::check_assumptions_satisfied () {
-  for (const auto & lit : assumptions) {
+  for (const auto &lit : assumptions) {
     // Not 'signed char' !!!!
     const int tmp = ival (lit);
-    if (tmp < 0) FATAL ("assumption %d falsified", lit);
-    if (!tmp) FATAL ("assumption %d unassigned", lit);
+    if (tmp < 0)
+      FATAL ("assumption %d falsified", lit);
+    if (!tmp)
+      FATAL ("assumption %d unassigned", lit);
   }
-  VERBOSE (1,
-    "checked that %zd assumptions are satisfied",
-    assumptions.size ());
+  VERBOSE (1, "checked that %zd assumptions are satisfied",
+           assumptions.size ());
 }
 
 void External::check_constraint_satisfied () {
@@ -403,15 +656,17 @@ void External::check_constraint_satisfied () {
 }
 
 void External::check_failing () {
-  Solver * checker = new Solver ();
+  Solver *checker = new Solver ();
   checker->prefix ("checker ");
 #ifdef LOGGING
-  if (internal->opts.log) checker->set ("log", true);
+  if (internal->opts.log)
+    checker->set ("log", true);
 #endif
   for (const auto lit : original)
     checker->add (lit);
   for (const auto lit : assumptions) {
-    if (!failed (lit)) continue;
+    if (!failed (lit))
+      continue;
     LOG ("checking failed literal %d in core", lit);
     checker->add (lit);
     checker->add (0);
@@ -423,11 +678,11 @@ void External::check_failing () {
   } else if (constraint.size ())
     LOG (constraint, "constraint satisfied and ignored");
   int res = checker->solve ();
-  if (res != 20) FATAL ("failed assumptions do not form a core");
+  if (res != 20)
+    FATAL ("failed assumptions do not form a core");
   delete checker;
-  VERBOSE (1,
-    "checked that %zd failing assumptions form a core",
-    assumptions.size ());
+  VERBOSE (1, "checked that %zd failing assumptions form a core",
+           assumptions.size ());
 }
 
 /*------------------------------------------------------------------------*/
@@ -460,9 +715,9 @@ void External::check_failing () {
 // continue;' check in it.  This has however the down-side that those units
 // are still in the simplified formula and only as units.  I would not
 // consider such a formula as really being 'simplified'. On the other hand
-// if the user explicitly freezes a literal, then it should continue to be in
-// the simplified formula during traversal.  So also only using the second
-// function is not ideal.
+// if the user explicitly freezes a literal, then it should continue to be
+// in the simplified formula during traversal.  So also only using the
+// second function is not ideal.
 
 // There is however a catch where this solution breaks down (in the sense of
 // producing less optimal results - that is keeping units in the formula
@@ -478,17 +733,18 @@ void External::check_failing () {
 // makes a difference in terms of traversing such a unit as unit clause or
 // as unit witness.
 
-bool
-External::traverse_all_frozen_units_as_clauses (ClauseIterator & it)
-{
-  if (internal->unsat) return true;
+bool External::traverse_all_frozen_units_as_clauses (ClauseIterator &it) {
+  if (internal->unsat)
+    return true;
 
   vector<int> clause;
 
   for (auto idx : vars) {
-    if (!frozen (idx)) continue;
+    if (!frozen (idx))
+      continue;
     const int tmp = fixed (idx);
-    if (!tmp) continue;
+    if (!tmp)
+      continue;
     int unit = tmp < 0 ? -idx : idx;
     clause.push_back (unit);
     if (!it.clause (clause))
@@ -499,17 +755,19 @@ External::traverse_all_frozen_units_as_clauses (ClauseIterator & it)
   return true;
 }
 
-bool
-External::traverse_all_non_frozen_units_as_witnesses (WitnessIterator & it)
-{
-  if (internal->unsat) return true;
+bool External::traverse_all_non_frozen_units_as_witnesses (
+    WitnessIterator &it) {
+  if (internal->unsat)
+    return true;
 
   vector<int> clause_and_witness;
 
   for (auto idx : vars) {
-    if (frozen (idx)) continue;
+    if (frozen (idx))
+      continue;
     const int tmp = fixed (idx);
-    if (!tmp) continue;
+    if (!tmp)
+      continue;
     int unit = tmp < 0 ? -idx : idx;
     clause_and_witness.push_back (unit);
     if (!it.witness (clause_and_witness, clause_and_witness))
@@ -522,21 +780,25 @@ External::traverse_all_non_frozen_units_as_witnesses (WitnessIterator & it)
 
 /*------------------------------------------------------------------------*/
 
-void External::copy_flags (External & other) const {
-  const vector<Flags> & this_ftab = internal->ftab;
-  vector<Flags> & other_ftab = other.internal->ftab;
+void External::copy_flags (External &other) const {
+  const vector<Flags> &this_ftab = internal->ftab;
+  vector<Flags> &other_ftab = other.internal->ftab;
   const unsigned limit = min (max_var, other.max_var);
   for (unsigned eidx = 1; eidx <= limit; eidx++) {
     const int this_ilit = e2i[eidx];
-    if (!this_ilit) continue;
+    if (!this_ilit)
+      continue;
     const int other_ilit = other.e2i[eidx];
-    if (!other_ilit) continue;
-    if (!internal->active (this_ilit)) continue;
-    if (!other.internal->active (other_ilit)) continue;
+    if (!other_ilit)
+      continue;
+    if (!internal->active (this_ilit))
+      continue;
+    if (!other.internal->active (other_ilit))
+      continue;
     assert (this_ilit != INT_MIN);
     assert (other_ilit != INT_MIN);
-    const Flags & this_flags = this_ftab[abs (this_ilit)];
-    Flags & other_flags = other_ftab[abs (other_ilit)];
+    const Flags &this_flags = this_ftab[abs (this_ilit)];
+    Flags &other_flags = other_ftab[abs (other_ilit)];
     this_flags.copy (other_flags);
   }
 }
@@ -564,7 +826,7 @@ void External::export_learned_unit_clause (int ilit) {
     LOG ("not exporting learned unit clause");
 }
 
-void External::export_learned_large_clause (const vector<int> & clause) {
+void External::export_learned_large_clause (const vector<int> &clause) {
   assert (learner);
   size_t size = clause.size ();
   assert (size <= (unsigned) INT_MAX);
@@ -580,4 +842,4 @@ void External::export_learned_large_clause (const vector<int> & clause) {
     LOG ("not exporting learned clause of size %zu", size);
 }
 
-}
+} // namespace CaDiCaL
