@@ -2,14 +2,14 @@
 
 namespace CaDiCaL {
 
-void Internal::copy_phases (vector<signed char> & dst) {
+void Internal::copy_phases (vector<signed char> &dst) {
   START (copy);
   for (auto i : vars)
     dst[i] = phases.saved[i];
   STOP (copy);
 }
 
-void Internal::clear_phases (vector<signed char> & dst) {
+void Internal::clear_phases (vector<signed char> &dst) {
   START (copy);
   for (auto i : vars)
     dst[i] = 0;
@@ -20,7 +20,10 @@ void Internal::phase (int lit) {
   const int idx = vidx (lit);
   signed char old_forced_phase = phases.forced[idx];
   signed char new_forced_phase = sign (lit);
-  if (old_forced_phase == new_forced_phase) return;
+  if (old_forced_phase == new_forced_phase) {
+    LOG ("forced phase remains at %d", old_forced_phase * idx);
+    return;
+  }
   if (old_forced_phase)
     LOG ("overwriting old forced phase %d", old_forced_phase * idx);
   LOG ("new forced phase %d", new_forced_phase * idx);
@@ -30,9 +33,12 @@ void Internal::phase (int lit) {
 void Internal::unphase (int lit) {
   const int idx = vidx (lit);
   signed char old_forced_phase = phases.forced[idx];
-  if (!old_forced_phase) return;
+  if (!old_forced_phase) {
+    LOG ("forced phase of %d already reset", lit);
+    return;
+  }
   LOG ("clearing old forced phase %d", old_forced_phase * idx);
   phases.forced[idx] = 0;
 }
 
-}
+} // namespace CaDiCaL
