@@ -9,6 +9,6 @@ double absolute_process_time ();
 uint64_t maximum_resident_set_size ();
 uint64_t current_resident_set_size ();
 
-}
+} // namespace CaDiCaL
 
 #endif // ifndef _resources_hpp_INCLUDED
