@@ -4,13 +4,13 @@
 namespace CaDiCaL {
 
 struct score_smaller {
-  Internal * internal;
-  score_smaller (Internal * i) : internal (i) { }
-  bool operator () (unsigned a, unsigned b);
+  Internal *internal;
+  score_smaller (Internal *i) : internal (i) {}
+  bool operator() (unsigned a, unsigned b);
 };
 
 typedef heap<score_smaller> ScoreSchedule;
 
-}
+} // namespace CaDiCaL
 
 #endif
