@@ -7,8 +7,8 @@ namespace CaDiCaL {
 
 class Handler {
 public:
-  Handler () { }
-  virtual ~Handler () { }
+  Handler () {}
+  virtual ~Handler () {}
   virtual void catch_signal (int sig) = 0;
 #ifndef __WIN32
   virtual void catch_alarm ();
@@ -18,7 +18,6 @@ public:
 class Signal {
 
 public:
-
   static void set (Handler *);
   static void reset ();
 #ifndef __WIN32
@@ -26,9 +25,9 @@ public:
   static void reset_alarm ();
 #endif
 
-  static const char * name (int sig);
+  static const char *name (int sig);
 };
 
-}
+} // namespace CaDiCaL
 
 #endif
