@@ -12,11 +12,11 @@ struct Var {
   // Note that none of these members is valid unless the variable is
   // assigned.  During unassigning a variable we do not reset it.
 
-  int level;         // decision level
-  int trail;         // trail height at assignment
-  Clause * reason;   // implication graph edge during search
+  int level;      // decision level
+  int trail;      // trail height at assignment
+  Clause *reason; // implication graph edge during search
 };
 
-}
+} // namespace CaDiCaL
 
 #endif
